@@ -30,7 +30,7 @@ class QualityProcessStep(Object):
   
     @property
     def endpoint(self):
-        return f"/qualityprocess/{self.quality_process.guid}/steps/{self.guid}"
+        return f"/qualityprocesses/{self.quality_process.guid}/steps/{self.guid}"
 
     @property
     @lazy
@@ -79,7 +79,15 @@ class QualityProcessStep(Object):
         return self._client._post(
             f"/qualityprocess/statuschanges",
             data=data
-            )  
+            )
+
+    @property
+    @lazy
+    def attributes(self):
+        attrs = [self._client.QualityProcessAttribute(**kwargs) for kwargs in self.__dict__
+        for step in steps:
+            step.quality_process = self
+        return attrs
 
 class QualityProcessTemplate(Object):
     listing_endpoint="/settings/qualityprocesses/templates"
@@ -102,9 +110,11 @@ class QualityProcessTemplate(Object):
         for step in steps:
             step.template=self
 
+        return steps
+
 class QualityProcessTemplateStep(Object):
     pass
 
-class QualityAttribute(Object):
-
-    listing_endpoint="/settings/quality/attributes"
\ No newline at end of file
+class QualityProcessAttribute(Object):
+    
+    def update(self, value)
\ No newline at end of file
